<?php
/**
 * @file
 * Send patches to testing master server. (Partial code, for drupal.org: 5.x)
 *
 * Copyright 2008 by Jimmy Berry ("boombatower", http://drupal.org/user/214218)
 */

/**
 * Settings form.
 */
function _pifr_settings_form() {
  $form = array();

  $form['project_server'] = array(
    '#type' => 'fieldset',
    '#title' => t('Project server'),
    '#description' => t('Configure project server details.'),
    '#collapsible' => TRUE,
  );
  $form['project_server']['pifr_project_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Key'),
    '#description' => t('The key used to confirm the server\'s identity.'),
    '#default_value' => variable_get('pifr_project_key', '')
  );

  $form['test_master'] = array(
    '#type' => 'fieldset',
    '#title' => t('Testing master server'),
    '#description' => t('Configure testing master server location and details.'),
    '#collapsible' => TRUE,
  );
  $form['test_master']['pifr_test_master_url'] = array(
    '#type' => 'textfield',
    '#title' => t('URL'),
    '#description' => t('The base URL of the testing master server ending with a forward slash.'),
    '#default_value' => variable_get('pifr_test_master_url', '')
  );
  $form['test_master']['pifr_test_master_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Key'),
    '#description' => t('The key used to confirm the server\'s identity.'),
    '#default_value' => variable_get('pifr_test_master_key', '')
  );

  $form['test_criteria'] = array(
    '#type' => 'fieldset',
    '#title' => t('Testing criteria'),
    '#description' => t('Configure the criteria that must be met for a file to be tested.'),
    '#collapsible' => TRUE,
  );
  $form['test_criteria']['pifr_project'] = array(
    '#type' => 'select',
    '#title' => t('Project'),
    '#description' => t('File must be of an issue related to one of the selected projects.'),
    '#options' => project_projects_select_options($project_urls),
    '#default_value' => variable_get('pifr_project', array()),
    '#multiple' => TRUE,
    '#size' => 6
  );
  $form['test_criteria']['pifr_component'] = array(
    '#type' => 'textarea',
    '#title' => t('Ignore Component'),
    '#description' => t('File must be of an issue that is not in the list of components. (One per line)'),
    '#default_value' => variable_get('pifr_component', ''),
    '#multiple' => TRUE,
    '#size' => 6
  );
  $form['test_criteria']['pifr_release'] = array(
    '#type' => 'textarea',
    '#title' => t('Release NID'),
    '#description' => t('File must be of an issue that is in the list of release NIDs. (One per line)'),
    '#default_value' => variable_get('pifr_release', ''),
    '#multiple' => TRUE,
    '#size' => 6
  );
  $form['test_criteria']['pifr_status'] = array(
    '#type' => 'select',
    '#title' => t('Status'),
    '#description' => t('File must be of an issue with one of the selected statuses.'),
    '#options' => project_issue_state(),
    '#default_value' => variable_get('pifr_status', array()),
    '#multiple' => TRUE,
    '#size' => 6
  );
  $form['test_criteria']['pifr_regex'] = array(
    '#type' => 'textfield',
    '#title' => t('Regular expression match'),
    '#description' => t('The regular expression to match filenames against. (<a href="@link">MySQL convention</a>)',
                        array('@link' => 'http://dev.mysql.com/doc/refman/5.0/en/regexp.html')),
    '#default_value' => variable_get('pifr_regex', '\.(patch|diff)$')
  );

  $form['test_frequency'] = array(
    '#type' => 'fieldset',
    '#title' => t('Testing frequency'),
    '#description' => t('Configure the frequency at which files will be sent for testing.'),
    '#collapsible' => TRUE,
  );
  $form['test_frequency']['pifr_fresh_cron_delay'] = array(
    '#type' => 'textfield',
    '#title' => t('Fresh'),
    '#description' => t('Frequency in minutes to send newly posted files for testing.'),
    '#default_value' => variable_get('pifr_fresh_cron_delay', '5'),
    '#size' => 4
  );
  $form['test_frequency']['pifr_all_cron_delay'] = array(
    '#type' => 'textfield',
    '#title' => t('All'),
    '#description' => t('Frequency in hours to send all eligible files for testing.'),
    '#default_value' => variable_get('pifr_all_cron_delay', '48'),
    '#size' => 4
  );

  $form['test_report'] = array(
    '#type' => 'fieldset',
    '#title' => t('Result reporting'),
    '#description' => t('Configure the result reporting information.'),
    '#collapsible' => TRUE,
  );
  $form['test_report']['pifr_report_fail_status'] = array(
    '#type' => 'select',
    '#title' => t('Fail status'),
    '#description' => t('Status to set issue to when tests failed.'),
    '#options' => project_issue_state(),
    '#default_value' => variable_get('pifr_report_fail_status', ''),
    '#size' => 6
  );

  return system_settings_form($form);
}
